@@ -129,10 +129,16 @@ void MainWindow::oldfonts(QString preset)
 
 void MainWindow::readdirs()
 {
-    QDir colors("/usr/share/icons");
-    QStringList colorstobox = colors.entryList(QDir::AllDirs | QDir::NoDotAndDotDot, QDir::DirsFirst);
-    colorstobox.removeOne("default");
-    ui->Iconset->addItems(colorstobox);
+    QDir colors("/usr/share/icons");   
+    QStringList temp = colors.entryList(QDir::AllDirs | QDir::NoDotAndDotDot, QDir::DirsFirst);
+    QStringList colorstobox;
+    int count = temp.count();
+    for(int i=0;i<count;i++)
+    {
+        if (QFile::exists("/usr/share/icons/" + temp.at(i) + "/index.theme")) {
+            ui->Iconset->addItem(temp.at(i));
+        }
+    }
 }
 
 void MainWindow::readgtkrc()
@@ -743,7 +749,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-32<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-34<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -901,6 +907,7 @@ void MainWindow::loadclicked()
 
 void MainWindow::delclicked()
 {
+ //   ManWin->hide();
     QFile file("/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentItem()->text());
     QMessageBox msgBox;
     msgBox.setWindowTitle(tr("Delete color preset?"));
@@ -909,12 +916,14 @@ void MainWindow::delclicked()
     msgBox.setDefaultButton(QMessageBox::Yes);
     msgBox.button(msgBox.Yes)->setText(tr("Yes"));
     msgBox.button(msgBox.No)->setText(tr("No"));
+    ManWin->hide();
     int ret = msgBox.exec();
 
     if ( ret == QMessageBox::Yes ) {
 
         if (file.exists()) file.remove();
-        ManWin->hide();
+        ManWin = new managepresets(this);
+        ManWin->show();
         QMaemo5InformationBox::information(this, tr("Preset deleted."), QMaemo5InformationBox::DefaultTimeout);
 
     }
@@ -993,3 +1002,42 @@ void MainWindow::savetheme()
         runscript("saveonly");
     }
 }
+
+void MainWindow::on_actionDelete_saved_themes_triggered()
+{
+    ManThemeWin = new managethemes(this);
+    connect(ManThemeWin->ui->deletebutton, SIGNAL(clicked()), this, SLOT(deletetheme()));
+    ManThemeWin->show();
+}
+
+void MainWindow::deletetheme()
+{
+    QString themetodelete = ManThemeWin->ui->themelist->currentItem()->text();
+    QString check1 = QFileInfo("/opt/usr/share/themes/" + themetodelete + "/createdbythemecustomizer").canonicalFilePath();
+    QString check2 = QFileInfo("/etc/hildon/theme/createdbythemecustomizer").canonicalFilePath();
+    if ( check1 == check2 ) {
+        QMaemo5InformationBox::information(this, tr("Selected theme is currently in use!") + "<br><br>" + tr("You can't delete a theme that's currently active."), QMaemo5InformationBox::NoTimeout);
+        return;
+    }
+    QMessageBox msgBox;
+    QStringList systemcommand;
+    systemcommand << "deletethemepushed" << themetodelete;
+    msgBox.setWindowTitle(tr("Delete theme?"));
+    msgBox.setText(tr("Are you sure you want to delete this theme?"));
+    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    msgBox.setDefaultButton(QMessageBox::Yes);
+    msgBox.button(msgBox.Yes)->setText(tr("Yes"));
+    msgBox.button(msgBox.No)->setText(tr("No"));
+    ManThemeWin->hide();
+    int ret = msgBox.exec();
+
+    if ( ret == QMessageBox::Yes ) {
+        QProcess *muoks0 = new QProcess(this);
+        muoks0->start("/sbin/launchcustomizer", systemcommand);
+        muoks0->waitForFinished();
+        QMaemo5InformationBox::information(this, tr("Theme deleted."), QMaemo5InformationBox::DefaultTimeout);
+        ManThemeWin = new managethemes(this);
+        ManThemeWin->show();
+
+    }
+}
