@@ -13,6 +13,36 @@
         <source>Restore theme files</source>
         <translation>Återställ temafiler</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Delete saved themes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Selected theme is currently in use!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You can&apos;t delete a theme that&apos;s currently active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Delete theme?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Are you sure you want to delete this theme?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Theme deleted.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>You must give name for the theme.</source>
@@ -518,4 +548,22 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>managethemes</name>
+    <message>
+        <location filename="managethemes.ui" line="0"/>
+        <source>Select theme:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="managethemes.ui" line="0"/>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="managethemes.cpp" line="0"/>
+        <source>No themes created by Theme Customizer found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
